==> aloe_django-0.0.19.tar.gz: aloe_django-0.0.19/README.md <==
Aloe-Django
=============

[![Build status](https://img.shields.io/travis/aloetesting/aloe_django.svg)](https://travis-ci.org/aloetesting/aloe_django)
[![Coverage](https://img.shields.io/coveralls/aloetesting/aloe_django.svg)](https://coveralls.io/github/aloetesting/aloe_django)
[![PyPI](https://img.shields.io/pypi/v/aloe_django.svg)](https://pypi.python.org/pypi/aloe_django)

Utilities for using [Aloe](https://github.com/aloetesting/aloe) with
[Django](http://djangoproject.com):

- A `harvest` command to run Gherkin tests
- A collection of steps to aid in testing Django applications

Install:

    pip install aloe_django

Read the [documentation](http://aloe.readthedocs.org/projects/aloe_django/en/latest/).

Aloe and Aloe-Django are based on [Lettuce](http://lettuce.it/).

License
-------

Aloe-Django - Django utils for Aloe based on Lettuce

Copyright (C) <2015> Alexey Kotlyarov <a@koterpillar.com>

Copyright (C) <2015> Danielle Madeley <danielle@madeley.id.au>

Copyright (C) <2013-2014> Infoxchange <devs@ix.org.au>


This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

==> aloe_django-0.2.0.tar.gz: aloe_django-0.2.0/README.md <==
Aloe-Django
=============

[![Build status](https://img.shields.io/travis/aloetesting/aloe_django.svg)](https://travis-ci.org/aloetesting/aloe_django)
[![Coverage](https://img.shields.io/coveralls/aloetesting/aloe_django.svg)](https://coveralls.io/github/aloetesting/aloe_django)
[![PyPI](https://img.shields.io/pypi/v/aloe_django.svg)](https://pypi.python.org/pypi/aloe_django)

Utilities for using [Aloe](https://github.com/aloetesting/aloe) with
[Django](http://djangoproject.com):

- A `harvest` command to run Gherkin tests
- A collection of steps to aid in testing Django applications

Install:

    pip install aloe_django

Read the [documentation](http://aloe.readthedocs.io/projects/aloe-django/).

Aloe and Aloe-Django are based on [Lettuce](http://lettuce.it/).

License
-------

Aloe-Django - Django utils for Aloe based on Lettuce

Copyright (C) <2015> Alexey Kotlyarov <a@koterpillar.com>

Copyright (C) <2015> Danielle Madeley <danielle@madeley.id.au>

Copyright (C) <2013-2014> Infoxchange <devs@ix.org.au>


This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
